@@ -3,7 +3,7 @@ package UniCodePoints;
 #warn 'export PERL_UNICODE=SD  # before running this app' 
 #  unless $ENV{PERL_UNICODE} =~ /S/ && $ENV{PERL_UNICODE} =~ /D/;
 
-use base 'Squatting';
+use Squatting;
 use strict;
 use warnings;
 
@@ -18,7 +18,6 @@ our %CONFIG = (
 );
 
 package UniCodePoints::Controllers;
-use Squatting ':controllers';
 our @C = (
   C(
     Home => [ '/' ],
@@ -38,7 +37,6 @@ our @C = (
 );
 
 package UniCodePoints::Views;
-use Squatting ':views';
 use HTML::AsSubs;
 
 sub x {
